"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AgentConfig = void 0;
const rxjs_1 = require("rxjs");
const constants_1 = require("../constants");
const error_1 = require("../error");
const logger_1 = require("../logger");
const CredentialAutoAcceptType_1 = require("../modules/credentials/models/CredentialAutoAcceptType");
const ProofAutoAcceptType_1 = require("../modules/proofs/ProofAutoAcceptType");
const types_1 = require("../types");
class AgentConfig {
    constructor(initConfig, agentDependencies) {
        var _a;
        // $stop is used for agent shutdown signal
        this.stop$ = new rxjs_1.Subject();
        this.initConfig = initConfig;
        this.label = initConfig.label;
        this.logger = (_a = initConfig.logger) !== null && _a !== void 0 ? _a : new logger_1.ConsoleLogger(logger_1.LogLevel.off);
        this.agentDependencies = agentDependencies;
        this.fileSystem = new agentDependencies.FileSystem();
        const { mediatorConnectionsInvite, clearDefaultMediator, defaultMediatorId } = this.initConfig;
        const allowOne = [mediatorConnectionsInvite, clearDefaultMediator, defaultMediatorId].filter((e) => e !== undefined);
        if (allowOne.length > 1) {
            throw new error_1.AriesFrameworkError(`Only one of 'mediatorConnectionsInvite', 'clearDefaultMediator' and 'defaultMediatorId' can be set as they negate each other`);
        }
    }
    get connectToIndyLedgersOnStartup() {
        var _a;
        return (_a = this.initConfig.connectToIndyLedgersOnStartup) !== null && _a !== void 0 ? _a : true;
    }
    get publicDidSeed() {
        return this.initConfig.publicDidSeed;
    }
    get indyLedgers() {
        var _a;
        return (_a = this.initConfig.indyLedgers) !== null && _a !== void 0 ? _a : [];
    }
    get walletConfig() {
        return this.initConfig.walletConfig;
    }
    get autoAcceptConnections() {
        var _a;
        return (_a = this.initConfig.autoAcceptConnections) !== null && _a !== void 0 ? _a : false;
    }
    get autoAcceptProofs() {
        var _a;
        return (_a = this.initConfig.autoAcceptProofs) !== null && _a !== void 0 ? _a : ProofAutoAcceptType_1.AutoAcceptProof.Never;
    }
    get autoAcceptCredentials() {
        var _a;
        return (_a = this.initConfig.autoAcceptCredentials) !== null && _a !== void 0 ? _a : CredentialAutoAcceptType_1.AutoAcceptCredential.Never;
    }
    get didCommMimeType() {
        var _a;
        return (_a = this.initConfig.didCommMimeType) !== null && _a !== void 0 ? _a : types_1.DidCommMimeType.V0;
    }
    get mediatorPollingInterval() {
        var _a;
        return (_a = this.initConfig.mediatorPollingInterval) !== null && _a !== void 0 ? _a : 5000;
    }
    get mediatorPickupStrategy() {
        return this.initConfig.mediatorPickupStrategy;
    }
    get maximumMessagePickup() {
        var _a;
        return (_a = this.initConfig.maximumMessagePickup) !== null && _a !== void 0 ? _a : 10;
    }
    get endpoints() {
        // if endpoints is not set, return queue endpoint
        // https://github.com/hyperledger/aries-rfcs/issues/405#issuecomment-582612875
        if (!this.initConfig.endpoints || this.initConfig.endpoints.length === 0) {
            return [constants_1.DID_COMM_TRANSPORT_QUEUE];
        }
        return this.initConfig.endpoints;
    }
    get mediatorConnectionsInvite() {
        return this.initConfig.mediatorConnectionsInvite;
    }
    get autoAcceptMediationRequests() {
        var _a;
        return (_a = this.initConfig.autoAcceptMediationRequests) !== null && _a !== void 0 ? _a : false;
    }
    get defaultMediatorId() {
        return this.initConfig.defaultMediatorId;
    }
    get clearDefaultMediator() {
        var _a;
        return (_a = this.initConfig.clearDefaultMediator) !== null && _a !== void 0 ? _a : false;
    }
    get useLegacyDidSovPrefix() {
        var _a;
        return (_a = this.initConfig.useLegacyDidSovPrefix) !== null && _a !== void 0 ? _a : false;
    }
    get connectionImageUrl() {
        return this.initConfig.connectionImageUrl;
    }
    get autoUpdateStorageOnStartup() {
        var _a;
        return (_a = this.initConfig.autoUpdateStorageOnStartup) !== null && _a !== void 0 ? _a : false;
    }
    extend(config) {
        return new AgentConfig(Object.assign(Object.assign(Object.assign({}, this.initConfig), { logger: this.logger, label: this.label }), config), this.agentDependencies);
    }
    toString() {
        const config = Object.assign(Object.assign({}, this.initConfig), { logger: this.logger !== undefined, agentDependencies: this.agentDependencies != undefined, label: this.label });
        return JSON.stringify(config, null, 2);
    }
}
exports.AgentConfig = AgentConfig;
//# sourceMappingURL=AgentConfig.js.map